==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ActivityFinalNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActivityFinalNode;
import io.ciera.tool.sql.ooaofooa.activity.ActivityFinalNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class ActivityFinalNodeSetImpl extends InstanceSet<ActivityFinalNodeSet,ActivityFinalNode> implements ActivityFinalNodeSet {

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ActivityFinalNode activityfinalnode : this ) activityfinalnode.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ActivityFinalNode activityfinalnode : this ) activityfinalnode.setId( ref_Id );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( ActivityFinalNode activityfinalnode : this ) controlnodeset.add( activityfinalnode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public ActivityFinalNode nullElement() {
        return ActivityFinalNodeImpl.EMPTY_ACTIVITYFINALNODE;
    }

    @Override
    public ActivityFinalNodeSet emptySet() {
      return new ActivityFinalNodeSetImpl();
    }

    @Override
    public ActivityFinalNodeSet value() {
        return this;
    }

    @Override
    public List<ActivityFinalNode> elements() {
        return Arrays.asList(toArray(new ActivityFinalNode[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ActivityFinalNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActivityFinalNode;
import io.ciera.tool.sql.ooaofooa.activity.ActivityFinalNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ActivityFinalNodeSetImpl extends InstanceSet<ActivityFinalNodeSet,ActivityFinalNode> implements ActivityFinalNodeSet {

    public ActivityFinalNodeSetImpl() {
    }

    public ActivityFinalNodeSetImpl(Comparator<? super ActivityFinalNode> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ActivityFinalNode activityfinalnode : this ) activityfinalnode.setDescrip( m_Descrip );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ActivityFinalNode activityfinalnode : this ) activityfinalnode.setId( ref_Id );
    }


    // selections
    @Override
    public ControlNodeSet R1106_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( ActivityFinalNode activityfinalnode : this ) controlnodeset.add( activityfinalnode.R1106_is_a_ControlNode() );
        return controlnodeset;
    }


    @Override
    public ActivityFinalNode nullElement() {
        return ActivityFinalNodeImpl.EMPTY_ACTIVITYFINALNODE;
    }

    @Override
    public ActivityFinalNodeSet emptySet() {
      return new ActivityFinalNodeSetImpl();
    }

    @Override
    public ActivityFinalNodeSet emptySet(Comparator<? super ActivityFinalNode> comp) {
      return new ActivityFinalNodeSetImpl(comp);
    }

    @Override
    public ActivityFinalNodeSet value() {
        return this;
    }

    @Override
    public List<ActivityFinalNode> elements() {
        return Arrays.asList(toArray(new ActivityFinalNode[0]));
    }

}
